@@ -2,8 +2,9 @@ pub mod auth;
 pub mod builder;
 pub mod client;
 pub mod config;
-pub mod encrypt;
 pub mod error;
+pub mod hook;
+pub mod oauth;
 pub mod pagination;
 pub mod repo;
 pub mod user;
